@@ -134,6 +134,11 @@
 #' @param timeStep
 #'   Resolution of the data to import: hourly (default), daily,
 #'   weekly, monthly or annual.
+#' @param mcWeights 
+#'   Vector of weights to apply to the specified mcYears. If not \code{NULL}, the vector must
+#'   be the same length as the vector provided in the \code{mcYear} parameter. The function
+#'   \code{readAntares} will then return the weighted synthetic results for the specified years,
+#'   with the specified weights.
 #' @param opts
 #'   list of simulation parameters returned by the function
 #'   \code{\link{setSimulationPath}}
@@ -205,6 +210,7 @@ readAntares <- function(areas = NULL, links = NULL, clusters = NULL,
                         select = NULL,
                         mcYears = NULL,
                         timeStep = c("hourly", "daily", "weekly", "monthly", "annual"),
+                        mcWeights = NULL,
                         opts = simOptions(),
                         parallel = FALSE, simplify = TRUE, showProgress = TRUE) {
   
@@ -242,6 +248,15 @@ readAntares <- function(areas = NULL, links = NULL, clusters = NULL,
   }
   
   
+  ##Control mcWeights
+  if(!is.null(mcWeights) & is.null(mcYears)){
+    stop("You cant used mcWeights for mc-all loaded")
+  }
+  
+  
+  
+  
+  
   if(!is.null(select)){
     if(!is.list(select)){
       if("all" %in% select){
@@ -293,6 +308,23 @@ readAntares <- function(areas = NULL, links = NULL, clusters = NULL,
   synthesis <- reqInfos$synthesis
   unselect <- reqInfos$unselect
   
+  
+  if(!is.null(mcWeights)){
+    if(showProgress == TRUE)cat("Aggregate mcYears with mcWeights \n")
+    return(aggregateResult(opts = opts,
+                    verbose = showProgress,
+                    filtering = TRUE,
+                    selected = list(areas = areas, links = links, clusters = clusters),
+                    timestep = timeStep,
+                    writeOutput = FALSE,
+                    mcWeights = mcWeights, mcYears = mcYears))
+  }
+  
+  
+  
+  
+  
+  
   if(length(reqInfos$computeAdd)>0)
   {
     for (v in reqInfos$computeAdd) {
